######################################################################
#:CQCC::MsgCat_Japanese
#
# Licensed Materials - Property of IBM
# Rational ClearCase
# (C) Copyright IBM Corp. 2001, 2009. All Rights Reserved.
# US Government Users Restricted Rights
# Use, duplication or disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
#

=head1 NAME

CQCC::MsgCat_Japanese - Message catalog for CQCC integration

=head1 CLASS DESCRIPTION

This class is subclass of CQCC::MsgCat which provides all the user
visible messages needed by the standard CQCC integration in the form
of message catalog entries. These will be used by called to the
IOPrompt(), IOMessage(), and IOListSelect methods to present user 
dialogs, messages, and menus.

In order to be used, the configuration file can ask for this 
class (default) or an alternate translation as shown below:

    &SetConfigParm("MessageCatalogInterface", "CQCC::MsgCat_Japanese");

Message prefixes indicate the class that uses the message and its
type: 

    CC (CCase)
    CQ (CQuest), CQP (CQPerlAPI), CQS (CQSchema), CQW (CQWeb)
    IO (IOBase), IOC (IOClearPrompt)
    PM (Parm)
    TBASE (TriggerBase), TCQCC (TriggerCQCC), TTEST (TriggerTest)

Types: E(rror), I(nfo), M(enu), P(rompt) 

Translations of this catalog should be done by following these steps:

1) Make a copy of this file, naming it MsgCat_<language>.pm where
   <language> is the name of the target language. 

2) Inside the copy, replace all instances of MsgCat_Japanese with 
   MsgCat_<language>. 

3) Translate the yes and no strings in the Initialize function. 
   These strings are embedded into the AddMsg calls later.

   Remove the YesNo method at the bottom of this file so that 
   YesNo matching is done using the base class method in MsgCat.pm

4) In the copy, edit each &AddMsg call to change only the third
   parameter. The %s markers indicate where the arguments (second
   paramater list) will be placed. Do not change the order of these.
   Do NOT add double-quotes (") within the body of the messages. 

   Note: Some messages are information about the config.pl parameters
   and are not yet used in the integration. These are less important.
   See the config.pl file for more information. 

5) Test the translation printout as follows: 

   Look for syntactic errors: 

      cqperl -cw -I.. MsgCat_<language>.pm 
    
   Review the output of the messages with arguments placeholders.

      cqcc_launch CQCC/config.pl -op classtest 
         CQCC::MsgCat_<language>

5) Modify the config file (CQCC/config.pl) to use the new
   translation: 

   &SetConfigParm("MessageCatalogInterface", 
       "CQCC::MsgCat_<language>");

   Use local environment variables if desired to set the message 
   catalog. 

SUPPORT POLICY: See TriggerCQCC.pm for the Rational Support Policy. 

=head1 METHODS

=cut

######################################################################
#::Package declarations
######################################################################

package CQCC::MsgCat_Japanese;
use utf8;
use CQCC::MsgCat;
@ISA = qw( CQCC::MsgCat );

use strict;
use CQCC::Parm;
sub Version { return '2.2' };

######################################################################
#::Class Globals 
######################################################################

my %arguments;      # Temp hash list for argument list during build
my %catalog;        # and message catalog

my $yes_string;     # Set during initialization from MsgCat vars
my $no_string; 
my $g_self;

######################################################################
#::method Classtest

=over 6

=item C<ClassTest(@args)>

This function creates a message catalog instance by calling
IOClassFactory(), calls the super classes SelfTest() method, 
then runs additional tests specific to this set of messages to
ensure we are able to look up messages and handle error conditions
properly. 

=back

=cut

#################################################################

sub ClassTest { 
    my @args = @_;
    my $msgcat = new CQCC::MsgCat_Japanese();

    $msgcat->SelfTest(@args);

    print "########################################\n";
    print "Test the message method with variety of cases\n";
    print "\n------\nShould complain about unknown msg key\n\n";
    print $msgcat->Message( [ "USAGE" ] );

    print "\n------\nShould show substitution for missing args\n\n";
    print $msgcat->Message( [ "TBASE_I_USAGE", "cqcc_trigger" ] );

    print "\n------\n", 
          "Should print correctly with cqcc_trigger as command\n\n";
    print $msgcat->Message( [ "TBASE_I_USAGE", "cqcc_trigger",
                            "cqcc_trigger", "cqcc_trigger" ]);

    print "\n------\nShould print out pathname at beginning\n\n";
    print $msgcat->Message( [ "CC_E_VOLIST", "<pathname>" ]) . "\n";
    return 0;
} 

#################################################################
#::method Initialize

=over 6

=item C<Initialize()>

This method is used to load the message catalog with tagged entries
and their arguments. Each message uses AddMsg() to add the msg tag
value, arglist and catalog entries to local hashlists that will be
stored into the object after the initialization is complete by the new
method.

=back

=cut

######################################################################

sub Initialize { 
    my $self = shift;
 
#################################################################
#:::CC_*:    CCase class messages

##################################################

#::::CC_E:  Error messages

    &AddMsg("CC_E_NO_HLINK", [ "<ERRMSG>" ],
"Clearcase は新規の関連付けへのハイパーリンクを作成できません:
%s");

    #----------------------------------------
    &AddMsg("CC_E_VOLIST",   [ "<PATHNAME>" ],
"Clearcase は、%s の固有 ID を取得できません。  
関連付けを作成または更新することができません。  リカバリーするには、
このファイルのチェックアウトをキャンセルし (keep または save オプションで
変更を保存して)、ファイルを再びチェックアウトし、変更を復元して、ファイルを
再びチェックインしてください。"); 

    #----------------------------------------
    &AddMsg("CC_E_CONFIG_SPEC_CONFLICT",   [ ],
"現在の構\成仕様ではチェックアウトされたエレメントが選択されていません。 
サイトでチェックイン前のトリガのみが使用される場合、この構\成仕様はサポートされません。
構\成仕様を変更してチェックアウトされたエレメントを選択するか、
または PostCheckin Commit トリガを使用可能\にするように管理者に依頼してください。");

#################################################################
#:::CQ_*:    CQuest class messages

##################################################

#::::CQ_E:  Error messages

    &AddMsg("CQ_E_ASSOC_NOT_ALLOWED", 
             [ "<BAD_IDS>", "<RESTRICTIONS>" ],
"以下の関連付けは受け入れられません。

%s

これらは以下のローカルの制限を満たしません。 

%s");

    #----------------------------------------
    &AddMsg("CQ_E_LOGIN_FAILED", [ "<DATABASE>" ],
"保存されたユーザー名とパスワードで ClearQuest データベース %s に
ログインすることに失敗しました。つまり、使用しているデータベース リポジトリが間違っているか、
またはログオン名とパスワードが間違っています。 
ログオン名とパスワードを再入力しますか?");

    #----------------------------------------
    &AddMsg("CQ_E_MIXED_ENTITIES", [ "<RECTYPE_DB_LIST>" ],
"現在この統合では、同じ関連付けリスト内での異なる
データベースおよびレコード タイプの混合使用はサポートされません。

%s");

    #----------------------------------------
    &AddMsg("CQ_E_NO_VALID_SCHEMA",  ["<DATABASE>", "<RECORD TYPE>"],
"データベース/エンティティを確認してください:
 %s : %s の
     構\成ファイルにスキーマが見つかりません。");

    #----------------------------------------
    &AddMsg("CQ_E_OP_UNSUPPORTED", [ "<CLASS>", "<OP>" ],
"Clearquest %s では以下の操作はサポートされていません: %s");

    #----------------------------------------
    &AddMsg("CQ_E_TEST_LOGIN_FAILED", [ ],
"テスト ユーザー名およびパスワードで ClearQuest データベースに
ログインすることに失敗しました");

    #----------------------------------------
    &AddMsg("CQ_E_UNKNOWN_DATABASE",  ["<DBNAME>"],
"ClearQuest はデータベース %s の使用に切り替えることができません。");

    #----------------------------------------
    &AddMsg("CQ_E_UNKNOWN_ENTITY", ["<RECORD TYPE>"],
"ClearQuest クエリーが失敗しました。不明レコード タイプ: %s");

    #----------------------------------------
    &AddMsg("CQ_E_UNKNOWN_QUERY",  ["<QUERY>"],
"ClearQuest クエリーが失敗しました。不明または空のクエリー: %s");

    #----------------------------------------
    &AddMsg("CQ_E_UNKNOWN_RESULTS", ["<RESULTS>"],
"ClearQuest クエリーが失敗しました。不明または空の結果セット: %s");

    #----------------------------------------
    &AddMsg("CQ_E_UNKNOWN_REPLICA_NAME", [],
"複数サイトのサポートが有効ですが、データベース レプリカ名を
データベースから判別することができません。CQCC_REPLICA_NAME
構\成パラメータはデフォルト値を提供するように設定されていません。 
管理者に問い合わせてください。");

    #----------------------------------------
    &AddMsg("CQ_E_UNKNOWN_SCHEMA",  ["<RECORD TYPE>"],
"ClearQuest クエリーが失敗しました。レコード タイプ %s に
既知のスキーマはありません。");

##################################################
#::::CQ_P:  Prompt messages

    &AddMsg("CQ_P_LOGIN", [],
"ClearQuest データベースのユーザー名とパスワードを、スペースで区切って
入力してください:");

    &AddMsg("CQ_P_LOGIN_DIALOG", ["<DATABASE>"],
"ClearQuest データベース %s にログイン");

    &AddMsg("CQ_P_LOGIN_USER", ["<DATABASE>"],
"ClearQuest データベース %s にログイン
ユーザー名を入力してください");

    &AddMsg("CQ_P_LOGIN_PASSWORD", ["<MASK_FLAG>"],
"ClearQuest にログイン
パスワードを入力してください%s");

    #----------------------------------------
    &AddMsg("CQ_P_LOGIN_CLEAR", [ ],
"ClearQuest ログイン情報をクリアして、再度ログインしますか?");

#################################################################
#:::CQP_*:   CQPerlAPI class messages

##################################################
#::::CQPerlAPI Parameter descriptions

    &AddMsg("CQCC_WEB_DATABASE_SET", [], 
"CQCC_DATABASE_SET と類似していますが、CQWeb インターフェイスのみによって使用されます。
同じ値に設定されることも、されないこともあります。 デフォルト値はありません。");

##################################################
#::::CQP_E:  Error messages

    &AddMsg("CQP_E_ERRCHECK",      [ "<CALLER>", "<ERRMSG>" ],
"ClearQuest Perl API から %s にエラーがあることが報告されました:
%s");

    #----------------------------------------
    &AddMsg("CQP_E_CODE_PAGE_MISMATCH", [],
"ClearQuest データ コード ページは クライアント コード ページと一致しません。
データベースからの情報を表\示または変更することができません。");

    #----------------------------------------
    &AddMsg("CQP_E_UNKNOWN_DB", [ "<DATABASE>", "<DB_LIST>" ],
"指定のデータベース %s は、現在のデータベース リポジトリには
見つかりません。  以下のデータベースのみが見つかりました:
%s");

    #----------------------------------------
    &AddMsg("CQP_E_QUERY_INVALID", [ "<QUERY_NAME>", "<OPERATOR>" ],
"不明な操作 %s のため、
サイトの構\成ファイルで定義されている現在の ClearQuest クエリーは無効です。 
不明な操作の位置は %s です。");

    #----------------------------------------
    &AddMsg("CQP_E_WRONG_ENTITY", ["<RIGHT TYPE>", "<WRONG TYPE>"],
"ClearQuest クエリーは無効 - クエリーはレコード タイプ %s を
戻すよう期待されています。 しかし、クエリーは代わりに %s を戻しています。 
別のクエリーを選択してください。");

#################################################################
#:::CQS_*:   CQSchema class messages

##################################################

#::::CQS_E:  Error messages

    &AddMsg("CQS_E_UNKNOWN_KEY",   [ "<KEY>", "<SCHEMA>" ],
"DefineCQSchema - 不明キー (%s) が見つかりました。 
サイトの構\成ファイルで定義されたスキーマ (%s) で問題が生じます。");

    #----------------------------------------
    &AddMsg("CQS_E_UNKNOWN_QUERY", [ "<QUERY>", "<SCHEMA>" ],
"DefineCQSchema - 不明な制限クエリー (%s) が見つかりました。 
サイトの構\成ファイルで定義されたスキーマ (%s) に問題が生じます。\n");

    #----------------------------------------
    &AddMsg("CQS_E_CONVERSION_ERROR", [ "<FIELD>","<ERROR>"],
"CQSchema 情報フィールド %s の変換エラー:
%s");

#################################################################
#:::CQW_*:   CQWeb class messages

##################################################

#::::CQW_E:  Error messages

    &AddMsg("CQW_E_DATABASE_INVALID", [ "<ERRMSG>" ],
"ClearQuest データベース名は無効です。 通常、このメッセージは
ユーザー名またはパスワードが間違って渡されたことを示します。
%s");

    #----------------------------------------
    &AddMsg("CQW_E_INVALID_SERVER", [],
"ClearQuest Web サーバーに接続するための十分な情報がありません。 
サーバー (CQCC_SERVER) および Web ページ (CQCC_SERVERROOT) を指定する環境変数または
構\成変数を設定するか、または URL 全体 (CQCC_URL) を指定して
Web サーバーにアクセスする必要があります。 現在の操作はキャンセルされます。 \n");

    #----------------------------------------
    &AddMsg("CQW_E_OP_FAILED", [ "<WARNING>", "<ERRMSG>" ],
"ClearQuest Web サーバーから、現在の操作にエラーがあることが報告されました。
%s

%s");

    #----------------------------------------
    &AddMsg("CQW_E_POSTCOMMAND", ["<URL>"],
"メッセージの送信後に、ClearQuest Web サーバー接続によって戻された
結果はありません。 Web ブラウザを使用して %s に接続し、
持っているサーバー URL アドレスが機能\することを確認してください。XML 処理問題に
関するメッセージを受信した場合、これは正常に接続されたことを示します。");

################################################################
#:::CQWJ_*:   CQWebJava class messages

##################################################
#::::CQWJ_E:  Error messages

    #----------------------------------------
    &AddMsg("CQWJ_E_DATABASE_INVALID", [ "<ERRMSG>" ],
"ClearQuest Web データベース名は無効です。 通常、このメッセージは
ユーザー名またはパスワードが間違って渡されたことを示します。
%s");

    #----------------------------------------
    &AddMsg("CQWJ_E_DATABASE_SET_UNSET", [ "<PARM>" ],
"使用するデフォルトのデータベース セットを ClearQuest Web が提供するためには、
%s パラメータを設定しなければなりません。");

    #----------------------------------------
    &AddMsg("CQWJ_E_INVALID_SERVER", [],
"ClearQuest Web サーバーに接続するための十分な情報がありません。 
サーバー (CQCC_SERVER) および Web ページ (CQCC_SERVERROOT) を指定する環境変数
または構\成変数を設定する必要があります。現在の操作はキャンセルされます。 \n");

    #----------------------------------------
    &AddMsg("CQWJ_E_OP_FAILED", [ "<WARNING>", "<ERRMSG>" ],
"ClearQuest Web サーバーから、現在の操作にエラーがあることが報告されました。
%s

%s");

    #----------------------------------------
    &AddMsg("CQWJ_E_QUERY_ORDER", [ "<NAMES>" ],
"ClearQuest Web クエリーには最初に 'dbid' フィールドが含まれるか、
全く含まれないかのどちらかでなければなりません (%s)");

    #----------------------------------------
    &AddMsg("CQWJ_E_POSTCOMMAND", ["<URL>"],
"メッセージの送信後に、ClearQuest Web サーバー接続によって戻された
結果はありません。 Web ブラウザを使用して %s に接続し、
持っているサーバー URL アドレスが機能\することを確認してください。\n");

    #----------------------------------------
    &AddMsg("CQWJ_E_CONVERSION_ERROR", [ "<FIELD>","<ERROR>"],
"CQWebJava フィールド '%s' の変換エラー:
%s");

################################################################
#:::CQWJP_*:   CQWebJavaParser class messages

##################################################

#::::CQWJP_E:  Error messages

    &AddMsg("CQWJP_E_XML_ERROR", [ "<Message>" ],
"CQWebJava XML 解析エラー: %s\n");

    &AddMsg("CQWJP_E_UNEXPECTED_ELEMENT", [ "<ElementName>" ],
"CQWebJava XML パーサー processElement により予\期しないエレメント:
%s が見つかりました。\n");

################################################################
#:::IO_*:    IOBase class messages

##################################################
#::::IO_E:  Error messages

    &AddMsg("IO_E_ANSWER_RANGE", [ "<ANSWER>" ],
"回答 (%s) は期待される範囲外です。
(1) から (N) の間の数値を選択し、RETURN を押してください。");

    #----------------------------------------
    &AddMsg("IO_E_CCRC_REQTS", [], 
"ベース CC/CQ 統合を CCRC Web 環境で実行するには、
以下の条件を満たす必要があります。

(1) CQCC_CACHE_ROOT を構\成ファイルで設定することにより、トリガ呼び出しの間に
  統合が個々のユーザー パラメータ情報をキャッシュに入れることのできる
  中央ディレクトリが提供されるようにしなければならない。 

(2) CCRC サーバーは ClearCase 7.0.1 以降を実行していなければならない。\n");

    #----------------------------------------
    &AddMsg("IO_E_FACTORY_FAILED",
        [ "<CLASSINTERFACE>", "<CLASSNAME>" ],
"アプリケーションは、クラス %s (%s) の
インスタンスを作成できません。");

    #----------------------------------------
    &AddMsg("IO_E_FAILED_MKDIR", ["<DIR>", "<ERR>"],
"ディレクトリ %s を作成できません
%s");

    #----------------------------------------
    &AddMsg("IO_E_FAILED_FILE_OP", ["<OPERATION>", "<FILE1>", "<FILE2>", "<CALLER>"],
"IOFileOperation: 操作 %s が失敗しました。
使用したファイル: %s
および %s、
呼び出し元: %s");

    #----------------------------------------
    &AddMsg("IO_E_FAILED_FILE_LOCK", ["<MODE>", "<FILE>"],
"ファイル ロック (%s) を %s に対して取得できません。");

    #----------------------------------------
    &AddMsg("IO_E_INVALID_ATRIA_DIR", [],
"ClearCase ホーム ディレクトリを判別できません。
PATH 変数を修正して Clearcase を見つける場所を含めてください。");

    #----------------------------------------
    &AddMsg("IO_E_INVALID_FILE_OP", ["<OPERATION>", "<FILE1>", "<FILE2>", "<CALLER>"],
"不明なファイル操作 %s、
使用したファイル: %s
および %s、
呼び出し元: %s");

    #----------------------------------------
    &AddMsg("IO_E_INVALID_FILE_OUTPUT", ["<OPERATION>", "<FILE>"],
"不明なファイル出力モード %s、
使用したファイル: %s");

    #----------------------------------------
    &AddMsg("IO_E_INVALID_ROOT_DIR", [ "<BASEDIR>" ],
"ベース ディレクトリ %s が存在しないため、
新規サブディレクトリを作成できません。");

    #----------------------------------------
    &AddMsg("IO_E_INVALID_SERIES_KEY", [],
"一意のキーの CLEARCASE_SERIES_ID または CLEARCASE_PPID のいずれも判別できません。");

    #----------------------------------------
    &AddMsg("IO_E_INVALID_TEMP_DIR", [],
"統合が使用する一時ディレクトリを判別できません。 
TMPDIR、TMP、または TEMP 環境変数を設定してください。");

    #----------------------------------------
    &AddMsg("IO_E_MSGTAG_UNDEF", [],
"IOMessage ダイアログ ルーチンは未定義のメッセージ タグを取得しました");

    #----------------------------------------
    &AddMsg("IO_E_SINGLE_ANSWER", [],
"単一の値のみを入力してください。");

    #----------------------------------------
    &AddMsg("IO_E_MSGCAT_NOT_INITIALIZED", [],
"IOConvertString: メッセージ カタログが初期化されていません");

    &AddMsg("IO_E_OEM_ACP_MISMATCH", [ "<CODEPAGE>","<OEM_CODEPAGE>","<CODEPAGE_NUM>"],
"ローカル コード ページ (%s) が標準出力によって使用される
コード ページ (%s) と異なるため、表\示の問題の原因になる可能\性があります。
これを訂正するには、コマンド プロンプト ウィンドウで、'chcp %s' を
使用します。");

    #----------------------------------------
    &AddMsg("IO_E_NO_STDIN", [],
"ユーザーへのプロンプト表\示を試行中ですが、非対話型環境を実行しているため
継続することができません。");

##################################################
#::::IO_P:  Prompt messages

    &AddMsg("IO_P_LISTSELECT", ["<SUFFIX>" ], "
選択 %s を入力: ");

    #----------------------------------------
    &AddMsg("IO_P_MESSAGE", [], "継続しますか (y/n) ? ");

    #----------------------------------------
    &AddMsg("IO_P_PROMPT", [], " ");

    #----------------------------------------
    &AddMsg("IO_P_YES", [], "はい");

    #----------------------------------------
    &AddMsg("IO_P_NO", [], "いいえ");

    #----------------------------------------
    &AddMsg("IO_P_YES_NO", [], "(y/n)");

    #----------------------------------------
    &AddMsg("IO_P_USERNAME", [], "ユーザー名");

    #----------------------------------------
    &AddMsg("IO_P_PASSWORD", [], "パスワード");

    #----------------------------------------
    &AddMsg("IO_P_AUTOBREAK_WAIT", [], 
"続行する前に、共有リソ\ースを処理している別のプロセスの
完了を待っています。しばらくお待ちください");

    #----------------------------------------
    &AddMsg("INFO", [], "情報");

    #----------------------------------------
    &AddMsg("WARN", [], "警告");
 
    #----------------------------------------
    &AddMsg("ERROR", [], "エラー");

    #----------------------------------------
    &AddMsg("FATAL", [], "致命的");

################################################################
#:::Confirm/Cancel Interface Labels

    &AddMsg("BUTTON_TEXT_ABORT", [], "Abort");
    &AddMsg("BUTTON_TEXT_YES", [], "Yes");
    &AddMsg("BUTTON_TEXT_RETURN", [], "RETURN");
    &AddMsg("BUTTON_TEXT_ENTER", [], "ENTER");

################################################################
#:::IOPTK_*: IOPTK* class messages

##################################################
#::::IOPTK_E_*: Error messages

    &AddMsg("IOPTK_E_DUP_WIDGET", [ "<NAME>", "<PARENT>" ],
"%s に重複ウィジェット名が存在します。 親: %s");

    #----------------------------------------
    &AddMsg("IOPTK_E_UNKNOWN_PARENT", [ "<PARENT>","<NAME>"],
"不明な親 %s が見つかりました。 
問題がウィジェット %s で検出されました。");

    #----------------------------------------
    &AddMsg("IOPTK_E_UNKNOWN_SUBTYPE", [ "<SUBTYPE>","<CLASS>"],
"不明なサブタイプ %s が見つかりました。 
問題がウィジェット クラス %s で検出されました。");

    #----------------------------------------
    &AddMsg("IOPTK_E_UNKNOWN_WIDGET", [ "<NAME>" ],
"不明なウィジェット %s");

    #----------------------------------------
    &AddMsg("IOPTK_E_NOT_PARENT", [ "<PARENT>", "<NAME>" ],
"提案された親 %s は子ウィジェットを管理しません。 
問題がウィジェット %s に検出されました。");

    #----------------------------------------
    &AddMsg("IOPTK_E_CONVERSION_ERROR", [ "<ROUTINE>", "<ERROR>" ],
"ユーザー インターフェイス表\示で以下の変換エラーが発生しました (%s):
%s");

################################################################
#:::MC_*:    MsgCat class messages

################################################################
#:::MC_*:    MsgCat Error messages

    &AddMsg("MC_E_CONVERSION_ERROR", [ "<SOURCE>", "<DEST>", "<ERROR>" ],
"%s から %s へ文字列を変換中にエラーが発生しました。
%s");

    # NOTE: Should be ASCII safe
    &AddMsg("MC_E_CONVERSION_MARKER", [ ],
"(変換に失敗)");

    &AddMsg("MC_E_TRUNCATION_MARKER", [ ],
"... (エラー メッセージは切り詰められています)");

    &AddMsg("MC_E_I18N_ICONVEX_OK", [ ],
"コード ページ変換エラー: 成功");

    &AddMsg("MC_E_I18N_ICONVEX_INPUT_INCOMPLETE", [ ],
"コード ページ変換エラー: 入力バッファが不完全なマルチバイト文字で終わっています。");

    &AddMsg("MC_E_I18N_ICONVEX_OUTPUT_FULL", [ ],
"コード ページ変換エラー: 出力バッファに、出力に十分な余地がありません");

    &AddMsg("MC_E_I18N_ICONVEX_INPUT_CONV_ERROR", ["<STRING>","<ERRORS>"],
"コード ページ変換エラー: このような文字は入力文字セット内にありません。
文字列: '%s'
次の文字が無効です:
%s\n");

    &AddMsg("MC_E_I18N_ICONVEX_OUTPUT_CONV_ERROR", ["<STRING>","<ERRORS>"],
"コード ページ変換エラー: 出力文字セット内に有効な文字がありません。
文字列: '%s'
次の文字が無効です:
%s\n");

    &AddMsg("MC_E_I18N_ICONVEX_ERROR", [ ],
"コード ページ変換エラー: その他のエラー");

    &AddMsg("MC_E_I18N_ICONVEX_UNKNOWN_ERROR", [ ],
"コード ページ変換エラー: 不明なエラー");

    &AddMsg("MC_E_NON_ASCII_I18N_DISABLED_PRE_CC7", ["<STRING>","<ERRORS>"],
"非 ASCII 文字が見つかりましたが、コード ページ変換は有効になっていません。 
このリリースでは、非 ASCII 文字を扱うコード ページ変換はサポートされていません。 
ClearCase 管理者に連絡してください。 

文字列: '%s'
次の文字は ASCII 文字ではありません:
%s\n");

    &AddMsg("MC_E_NON_ASCII_I18N_DISABLED_CC7", ["<STRING>","<ERRORS>"],
"非 ASCII 文字が見つかりましたが、コード ページ変換は有効になっていません。 
Clearcase 管理者は、CQCC_I18N_ENABLE 構\成パラメータを設定してコード ページ変換を
有効にする必要があります。 

文字列: '%s'
次の文字は ASCII 文字ではありません:
%s\n");

#################################################################
#:::PM_*:    Parm class messages

##################################################
#::::PM_E:  Error messages

    &AddMsg("PM_E_PARM_RANGE",
             [ "<PARM>", "<VALUE>", "<MINIMUM>", "<MAXIMUM>" ],
"以下のパラメータ-値のペアで問題が検出されました。
パラメータ: %s、値: %s。
この値は受け入れられる範囲 (%s から %s) 外です");

    #----------------------------------------
    &AddMsg("PM_E_PARM_LIST", [ "<PARM>", "<VALUE>", "<LIST>" ],
"以下のパラメータ-値のペアで問題が検出されました。
パラメータ: %s、値: %s。
このパラメータは受け入れられるリスト %s 中に見つかりませんでした");

    #----------------------------------------
    &AddMsg("PM_E_TWO_PARMS", [ "<PARM>" ],
"2 つのパラメータが同じ名前を使用しているか、または 2 度定義されています:
%s");

    #----------------------------------------
    &AddMsg("PM_E_UNKNOWN_PARM", [ "<PARM>"],
"不明のパラメータ %s");

    #----------------------------------------
    &AddMsg("PM_E_CONVERSION_ERROR", [ "<PARM>","<VALUE>"],
"パラメータで検出された変換エラー: %s。 
パラメータに以下の値があります: %s");

#################################################################
#:::TBASE_*: TriggerBase class messages

##################################################
#::::TBASE_E:  Error messages

    &AddMsg("TBASE_E_BAD_RESULT", [ "<RESULT>", "<OPERATION>" ],
"予\期せぬ結果 (%s) が %s 操作から戻されました");

    #----------------------------------------
    &AddMsg("TBASE_E_UNKNOWN_ARG", [ "<ARGUMENT>" ],
"トリガ メニュー: 不明なコマンド行引数 %s");

    #----------------------------------------
    &AddMsg("TBASE_E_UNKNOWN_MENU", [ "<MENU>"],
"トリガ MenuDisplay: 不明なメニュー %s");

    #----------------------------------------
    &AddMsg("TBASE_E_UNKNOWN_METHOD", [ "<METHOD>" ],
"トリガ メニュー: 不明なコールバック メソ\ッド %s");

    #----------------------------------------
    &AddMsg("TBASE_E_UNKNOWN_SYSTEM", [ "<SYSTEM>" ],
"%s システムに接続できません");

    #----------------------------------------
    &AddMsg("TBASE_E_NO_OPERATION", [],
"トリガに操作が指定されていません");

    #----------------------------------------
    &AddMsg("TBASE_E_LOAD_CACHE_SERIES", ["<CACHE_FILE>"],
"LoadCache: チェックイン前シリーズのキャッシュ ファイルが見つかりません:
%s。
操作を継続するとデータがさらに失われる恐れがあります。
この問題を ClearCase 管理者に報告してください");

    #----------------------------------------
    &AddMsg("TBASE_E_SAVE_CACHE_SERIES", [],
"SaveCache: ClearCase プロセス ID およびシリーズ ID の両方が設定解除されているため、
チェックイン前のトリガからチェックイン後のトリガのために、必要な情報をキャッシュに入れる
ことができません。この問題を ClearCase 管理者に報告してください。");

##################################################
#::::TBASE_I:  Info  messages

    &AddMsg("TBASE_I_HELP", [], 
"このスクリプトはベース ClearCase-ClearQuest 統合をインプリメントします。 

スクリプトは通常、これらのオプション パラメータと共に ClearCase トリガとして
呼び出されます。  スクリプトは通常、ClearCase によって設定されるいくつかの
環境変数に依存するため、通常はスクリプトをコマンド行から実行することはありません。 
特殊な管理操作を実行するために、スクリプトをコマンド行から実行することが必要になる
場合があります。

以下の 2 つのパラメータが ClearCase トリガ呼び出しによって通常使用されます。

    -required  このパラメータでは、少なくとも 1 つの ClearQuest 変更依頼が、
               チェックアウトまたはチェックイン操作で関連付けられるよう、
    　    　   ユーザーが指定する必要があります。 このパラメータは
  　　  　　   チェックアウトの取り消し操作では無視されます。

    -entitydef <name>
               このパラメータを使用して、ClearQuest レコード タイプを
  　　  　　   ユーザーが作業する初期デフォルト レコード タイプとして
  　　  　　   指定します。 初期のデフォルト レコード タイプは
               'defect' (障害) です。 このパラメータはチェックアウト
  　　  　　   の取り消し操作では無視され、代わりに既存の関連付けと共に保存された
  　　  　　   レコード タイプが使用されます。

以下の 4 つのパラメータは、管理者がコマンド行からトリガを直接呼び出す場合に有用です。

    -help      このメッセージを作成して終了します。

    -usage     スクリプトへのコマンド行引数を説明します。

    -test      ClearQuest との接続をテストし、デフォルト データベース
               およびエンティティ (レコード タイプ) に対する STANDARD
               クエリーの出力を表\示します。 

               ClearQuest がローカルにインストールされている場合、
  　　  　　   統合は、ClearQuest メンテナンス ツールまたは
  　　  　　   UNIX 環境変数によって確立された接続に依存して、
  　　  　　   CQPERL および CQPerl API をデータベースに対して
               使用しようとします。 

               ClearQuest がローカルにインストールされていないか、
  　　  　　   または CQCC_CQWEB_ONLY パラメータが有効である場合、
  　　  　　   統合は CQWeb インターフェイスを使用します。 
               CQWeb インターフェイスは環境変数 CQCC_SERVER および
               CQCC_SERVERROOT (または CQCC_URL) を使用して、リモート
  　　  　     Windows ClearQuest Web サーバーとのセッションをセット
               アップしようとします。これは、no-op 命令を送信して、
               サーバー上の ASP ページで期待される応答が得られるか
               どうかを確認することによって行われます。 
　　  　     このテストにより、ClearQuest ユーザー名および
  　　  　　   パスワードが機能\するかどうかも確認されます。
               テスト モードでは、スクリプトは ClearCase と対話しません。 
　　  　　   テスト モードでスクリプトが失敗しても、これは ClearCase に
  　　  　　   問題があるからではありません。

    -vob       -vob オプションは、エンド ユーザーの便宜のために推奨
  　　  　　   されています。 これは、現在の VOB 内のチェックアウト
  　　  　     トリガから、主なコマンド行引数を取得するよう、トリガを
  　　  　　   起動するスクリプトに指示します。 これによって、正しい
               パスが cqcc_launch、構\成ファイル、およびトリガ ソ\ースに
               提供され、ユーザーがどこに構\成ファイルがあるかなどを心配するのを
               避けられます。ただし、このオプションを使用するには、アクティブな
  　　  　     トリガが中にある VOB 内からそうする必要があります。

以下の詳細設定パラメータは、トリガの開発者またはテスト担当者によって使用されます。

    -p parmName,parmValue
                このオプションは、指定された値に変更するコマンド行
                パラメータを指定します。 

    -op operation arg,arg,...
                このオプションは、classtest など、実行する操作と、
  　　  　　  　操作が使用する引数を指定します。 

                編集操作 (-op edit) は、チェックイン後に関連付けに
                対して変更を行うのに便利です。 これにより、必要な
  　　  　　  　バージョン パス名および VOB 情報のプロンプトが表\示され、
  　　  　　  　その後、メイン関連付けメニューが再表\示されます。 

                バッチ操作 (-op batch) は、CQCC_ASSOC_BATCH_ENABLE
  　　  　　  　オプションが使用されている場合に、手動で関連付け
  　　  　　  　バッチ ファイルの処理を強制する際に便利です。 デフォルトで、
  　　  　　  　この操作では構\成ファイルと同じ CQCC_ASSOC_BATCHFILE 設定が
                想定されますが、ファイル名は引数として指定できます。

    -central <path>
               -central オプションは、エンド ユーザーには推奨されません。 
               これは、中央トリガが使用中であるときに統合
  　　  　　   および config.pl ファイルがどこにあるかを示します。これは
               トリガ実行コマンドのみで使用するものです。 エンド ユーザー
  　　  　　   のアクセス用には、代わりに -vob オプションを使用します。

    -path <configPath>
               -path オプションは、トリガ起動スクリプトとメイン トリガ コードの
               間で、通知のみを目的として内部で使用されます。 

    -postop    -postop オプションは、実行されているトリガが、操作前トリガ
  　　  　　    (デフォルト) であるか、または操作後トリガ (スイッチが使用
  　　  　　   された場合)であるかを示します。 

    -silent    -silent オプションは、チェックアウトのみの状況における
               チェックインではユーザーとの対話をスキップすることを示します。 

このスクリプトの動作は、サイトの構\成ファイル CQCC/config.pl を編集することによって
修正できます。これを行う主な理由は、ClearQuest 付属の SAMPL スキーマ以外の ClearQuest
データベース スキーマを使って実行するようスクリプトを適応させることにあります。 
特に、クエリーを生成するためにこのスクリプトによって使用されるすべてのフィールド名が
(同一のスペルで)、データベース スキーマに存在している必要があります。 
使用しているスキーマに関する詳細は、ClearQuest 管理者に問い合わせてください。 \n");

    #----------------------------------------
    &AddMsg("TBASE_I_USAGE", 
             [ "<COMMAND>", "<COMMAND>", "<COMMAND>" ], 
"用法:
%s [-required] [-entitydef <name>] [-vob]
   -required - 少なくとも 1 つの変更依頼が指定されていなければならない場合に、
  　　  　フラグを立てます。 チェックアウトの取り消しでは無視されます。
   -entitydef - デフォルトは 'defect' (障害) です。 
          他のレコード タイプが使用される場合に設定します。
   -vob - 便宜のために、現在の VOB 内のトリガからの中央パスと
  　　  　構\成ファイル名を使用します。
   -p parm,value - コマンド行パラメータの値を設定します。
   -op operator arglist - 実行する操作を指定します。 
          通常、操作は CLEARCASE_OP_KIND 環境変数から判別されます。

または: %s -test - 必要な環境変数および CQ サーバーとの通信の設定を
          テストします。

または: %s -help - ヘルプ メッセージを出力して終了します。
          内部で使用されている追加の詳細パラメータを説明します。 \n");

#################################################################
#:::TCQCC_*, Action*, Dialog*, Menu: TriggerCQCC class messages

##################################################
#::::TriggerCQCC Parameter descriptions

    &AddMsg("CQCC_MULTIPLE_ASSOCS", [],
"このスイッチでは、ユーザーが操作ごとに、1 つのみの関連付けを
行うことができるか ('FALSE')、または複数の関連付けを行うことができるか
('TRUE'、デフォルト) を選択します。");

    &AddMsg("CQCC_AUTO_ASSOCIATE", [],
"このオプションを使用して、チェックアウトおよびチェックイン操作時に
ファイルと関連付ける 1 つ以上の変更依頼を指定します。 詳しくは、
README ファイルまたはオンライン ヘルプを参照してください。");

    &AddMsg("CQCC_AUTO_ASSOCIATE_ENABLE", [],
"このオプションを使用して、ユーザーに
CQCC_AUTO_ASSOCIATE オプションの使用を許可するかどうかを指定します。  
CQCC_AUTO_ASSOCIATE オプションの使用を禁止するには、
CQCC_AUTO_ASSOCIATE_ENABLE を \"FALSE\" に設定します。  
CQCC_AUTO_ASSOCIATE の使用を許可するには、
CQCC_AUTO_ASSOCIATE_ENABLE を \"TRUE\" に設定します。");

    &AddMsg("CQCC_COMMENT_PATTERN", [],
"このオプションを使用して、コメント パターンを指定します。
これによりユーザーは、パターンに一致するチェックインまたは
チェックアウト コメントを入力して関連付けを行うことができます。  
このようにすると、ユーザーは、ファイルを変更依頼に関連付けるための
統合のユーザー インターフェイスを開始することを回避できます。  
このオプションを有効にするには、Perl 式の形式でパターンを指定します。 
例えば、\"BUGS:\\\\[(\\\\S+)\\\\]\" に設定されたパターンは
\"This fixes  BUGS:[SAMPL1,2,3]\" に一致します。この例では
2 重のバックスラッシュで各バックスラッシュをエスケープしています。
ユーザーがチェックイン コマンドに入力する変更依頼は、
チェックアウト コマンドで指定した変更依頼をオーバーライドします。  
CQCC_AUTO_ASSOCIATE オプションが有効である場合には、
統合は関連付けを行う際に CQCC_COMMENT_PATTERN オプションではなく
CQCC_AUTO_ASSOCIATE オプションを使用します。");

    &AddMsg("CQCC_CQWEB_ONLY", [],
"このスイッチは、クライアントのマシンに ClearQuest と
CQPerl がある場合でも、CQWeb インターフェイスの使用を強制するために使用されます。");

    &AddMsg("CQCC_POSTCHECKIN_VERIFY", [], 
"チェックイン後、正しいオブジェクト ID が ClearQuest に保存されて
いることを確認してください。");

##################################################
#::::TCQCC_E:  Error messages

    &AddMsg("TCQCC_E_ASSOC_NOT_SPECIFIED", [],
"この操作に関連付ける ClearQuest 変更依頼を指定する必要があります。");

    #----------------------------------------
    &AddMsg("TCQCC_E_BATCH_INPUT_ERROR", ["<LINENUM>","<LINE>"], 
"バッチ ファイル入力行 %s を解析できません:
%s");

    #----------------------------------------
    &AddMsg("TCQCC_E_BATCH_INPUT_FAILED", ["<FILENAME>"], 
"バッチ入力ファイル %s を開くことができません");

    #----------------------------------------
    &AddMsg("TCQCC_E_BATCH_OUTPUT_FAILED", ["<FILENAME>"], 
"出力ファイル %s を開くことができません。
ClearCase および ClearQuest に直ちに変更を加えています");

    #----------------------------------------
    &AddMsg("TCQCC_E_BATCH_OP_FAILED", ["<FILENAME>"], 
"トランザクションのポストを報告するエラーのため、ClearQuest
トランザクション バッチ ファイル %s の処理を
完了することができません。 問題を解決し、別の ClearCase チェックアウト、
チェックアウトの取り消し、またはチェックイン操作を実行してバッチを再試行
するか、ローカル管理者に連絡して援助を求めてください。");

    #----------------------------------------
    &AddMsg("TCQCC_E_BATCH_UNKNOWN_OP", ["<OP>"], 
"バッチ操作のアクション パラメータが不明 (%s)。
次のいずれかでなければなりません: do、undo、または noop");

    #----------------------------------------
    &AddMsg("TCQCC_E_BUGLIST_INPUT", ["<DATA>", "<DBNAME>", "<RECTYPE>"], 
"入力リストにエラーがありました:
    %s
完全な ID を先行するデータベース名と共に入力するか、または数値のみを
入力するか、あるいは 2 つのモードの組み合わせを入力できます。 
データベース名を入力する場合、それは現在のデータベース名:
(%s) と一致していなければなりません。 
レコード タイプ名: (%s) も一致する必要があります。
情報を再入力してください。");

    #----------------------------------------
    &AddMsg("TCQCC_E_EXISTING_BUGS_LOCK_DB", [], 
"既存の関連付けがある場合、データベースを変更することはできません。");

    #----------------------------------------
    &AddMsg("TCQCC_E_GDTRIGGER_INCOMPATIBLE", [], 
"当初ホット フィックスとして提供された GDTrigger トリガ クラスは、
このバージョンのメイン トリガに取って代わられ、互換性がありません。");

    #----------------------------------------
    &AddMsg("TCQCC_E_NO_ASSOCS", [], 
"[確認] オプションは、提案された関連付けの既存のリストを表\示、またはそれから
削除するために使用されます。 編集できる既存の、または提案された関連付けは
ありません。 [クエリー] オプションを使用して ClearQuest クエリーから選択するか、
または [タイプ] オプションを使用して変更依頼 ID を直接入力してください。

チェックイン操作のために新規の変更依頼を作成する必要がある場合は、
ClearQuest を手動で開始し、新規項目を作成し、それから [クエリー]
または [タイプ] オプションを再び実行しなければなりません。\n");

    #----------------------------------------
    &AddMsg("TCQCC_E_NO_MULTI_ASSOCS", [], 
"ポリシー: 複数の関連付けは許可されません - チェックイン
またはチェックアウトごとに 1 つのみの関連付けを選択してください。");

    #----------------------------------------
    &AddMsg("TCQCC_E_QUERY_EMPTY", ["<USER>"],
"クエリーは、ユーザー '%s' に対して、開いている変更依頼を戻しませんでした");

    #----------------------------------------
    &AddMsg("TCQCC_E_WEB_NOT_SUPPORTED", [],
"ベース CC/CQ 統合は現在 ClearCase Web サーバーではサポートされていません");

    #----------------------------------------
    &AddMsg("TCQCC_E_SELECTION", [],
"リストから選択するか、または [キャンセル] を押して終了してください");

    #----------------------------------------
    &AddMsg("TCQCC_E_ID_MUST_BE_FIRST", ["<QUERY_NAME>"], 
"統合では、クエリーの 1 列目が ID フィールドであることが必要です。
このクエリー (%s) を修正するか、可能\であれば別のクエリーを選択してください");

##################################################
#::::TCQCC_I:  Info messages

    &AddMsg("TCQCC_I_BATCH_CONFIRM", [],
      "
ClearQuest トランザクションは正常にデータベースへポストされました。");

    #----------------------------------------
    &AddMsg("TCQCC_I_GETBUGS_HELP", [], 

"この ClearCase 操作で関連付ける ClearQuest 変更依頼のリストを
入力してください。  完全な ClearQuest 変更依頼 ID (SAMPL00000023
または SAMPL34) を入力するか、または数値のみ (000023 または 34) を
入力するか、あるいはスペースまたはコンマで区切られた任意の組み合わせを
入力できます。 指定するデータベースは現在ログインしているデータベース
と一致しなければなりません。一致しない場合はエラーが生じます。 

リストのプロンプト メッセージが [必須:] で始まる場合は、
ClearCase 操作が正常に完了するには、少なくとも 1 つの変更依頼 ID を
指定する必要があります。 関連付けがオプションであり、関連付けを
行わない場合には、[中断/キャンセル] をクリックするか、RETURN を押します。\n");

##################################################
#::::TCQCC_P:  Prompt messages

    &AddMsg("TCQCC_P_QUERY_RESULTS", ["<USER>"],
"ユーザー %s に割当てた変更依頼を開く");

    #----------------------------------------
    &AddMsg("TCQCC_P_QUERY_ASSOCLIST", ["<KEY>"],
"関連済みレコード:項目を選ぶか %s を押す");

    #----------------------------------------
    &AddMsg("TCQCC_P_VOBPN", [], "VOB タグを入力してください:");

    #----------------------------------------
    &AddMsg("TCQCC_P_XPN", [], "拡張パス名を入力してください:");

    #----------------------------------------
    &AddMsg("TCQCC_P_ENTER_BUGS_NOWARN_OPT",
            ["<OP>", "<FILE>"],
"(オプション) アクションに関連付ける ClearQuest 変更依頼 ID、ファイルに対する操作 (%s)、ファイル (%s) を、スペースまたはコンマで区切って入力します。 

関連付けを行わない場合は、RETURN を押します。");

    #----------------------------------------
    &AddMsg("TCQCC_P_ENTER_BUGS_NOWARN_REQD",
            ["<OP>", "<FILE>"],
"(必須) アクションに関連付ける ClearQuest 変更依頼 ID、ファイルに対する操作 (%s)、ファイル (%s) を、スペースまたはコンマで区切って入力します。 

関連付けを行わない場合は、RETURN を押します。");

##################################################
#::::Action_*:  TriggerCQCC Action menu items

    &AddMsg("Action_Cancel", [], "現在の操作のみをキャンセルする");

    #----------------------------------------
    &AddMsg("Action_Cancel_ApplyToAll", [],
"バッチ内の残りの操作をキャンセルする");

    #----------------------------------------
    &AddMsg("Action_Commit", [], 
"OK - 現在の関連付けを現在のファイルのみに適用する");

    #----------------------------------------
    &AddMsg("Action_Commit_ApplyToAll", [],
"OK - 現在の関連付けをバッチ内のすべてのファイルに適用する");

    #----------------------------------------
    &AddMsg("Action_Commit_ApplyToAll_UseCheckouts", [],
"OK - 元のチェックアウト関連付けをバッチ内のすべてのファイルに適用する");

    #----------------------------------------
    &AddMsg("Action_Return", [], "メインメニューに戻る");

    #----------------------------------------
    &AddMsg("Action_Help", [ "<TOPIC>" ],
"ヘルプ - このメニューのヘルプを表\示する");

    #----------------------------------------
    &AddMsg("Action_Noop", [], "------");

##################################################
#::::Dialog_*:  TriggerCQCC Dialog menu items

    &AddMsg("Dialog_Cancel", [], "キャンセル");

    #----------------------------------------
    &AddMsg("Dialog_Cancel_Menu", [], 
"バッチ操作中の変更をキャンセルする");

    #----------------------------------------
    &AddMsg("Dialog_Cancel_Help", [],
"一度に処理されているバージョンのバッチの途中であるため、
残りのバージョンを自動的に処理する方法を指定することができます。\n");

    #----------------------------------------
    &AddMsg("Dialog_Commit", [], "OK - 関連付けをコミットする");

    #----------------------------------------
    &AddMsg("Dialog_Commit_Help", [], 
"一度に処理されているバージョンのバッチの途中であるため、
残りのバージョンを自動的に処理する方法を指定することができます。\n");

    #----------------------------------------
    &AddMsg("Dialog_Commit_Menu", [], 
"バッチ操作中の関連付けをコミットする");

    #----------------------------------------
    &AddMsg("Dialog_EditDesiredAssocs", [ "<ASSOCLIST>" ],
"関連付けの確認: ( %s ) ...");

    #----------------------------------------
    &AddMsg("Dialog_SelectByTypein", [],
"タイプ - キーボードから関連付けを入力します ...");

    #----------------------------------------
    &AddMsg("Dialog_SelectByQuery", [], 
"クエリー - ClearQuest クエリーから選択します ...");

    #----------------------------------------
    &AddMsg("Dialog_SelectDatabase", [ "<DATABASE>" ],
"データベース (%s) ...");

    #----------------------------------------
    &AddMsg("Dialog_SelectEntity", [ "<ENTITY>" ], 
"レコード タイプ (%s) ...");

    #----------------------------------------
    &AddMsg("Dialog_DisplayXPN", [ "<PATHNAME>" ],
"パス名 (%s) ...");

    #----------------------------------------
    &AddMsg("Dialog_SelectQueryName", [ "<QUERYNAME>" ],
"クエリー名 (%s) ...");

    #----------------------------------------
    &AddMsg("Action_ClearCQLogin", [ ],
"ClearQuest に再ログインする");

##################################################
#::::GUI_*:  TriggerCQCC GUI tags

    &AddMsg("GUI_Title_CQCC_Integration", [], 
        "ClearCase と ClearQuest の統合");

    #----------------------------------------
    # Menu 1 - Associated Records and main operations

    &AddMsg("GUI_Title_AssocRecords", [], "関連付けられたレコード:");
    &AddMsg("GUI_Commit", [], "OK");
    &AddMsg("GUI_Cancel", [], "キャンセル");
    &AddMsg("GUI_ApplyToAll", [], "すべてに適用");
    &AddMsg("GUI_Disassociate", [], "関連付け解除");
    &AddMsg("GUI_ClearCQLogin", [], "ClearQuest に再ログインする");
    &AddMsg("GUI_Help", [], "ヘルプ");

    #----------------------------------------
    # Mid bar buttons

    &AddMsg("GUI_Database", [], "データベース");
    &AddMsg("GUI_RecordType", [], "レコード タイプ");

    #----------------------------------------
    # Menu 2 - Query Results and related operations

    &AddMsg("GUI_Title_Query", [], "クエリー:");
    &AddMsg("GUI_Title_Results", [], "結果");
    &AddMsg("GUI_Browse", [], "参照...");
    &AddMsg("GUI_Associate", [], "関連付け");
    &AddMsg("GUI_Refresh", [], "リフレッシュ");
    &AddMsg("GUI_Typein", [], "ID を入力");

    #----------------------------------------
    # Query Browser Dialog

    &AddMsg("GUI_Title_SelectQuery", [], "クエリーの選択");

    #----------------------------------------
    # IOPerlTK Dialog Box messages

    &AddMsg("GUI_ListSelect", [], "リストから選択");
    &AddMsg("GUI_Message", [], "メッセージ");
    &AddMsg("GUI_Prompt", [], "プロンプト");

    #----------------------------------------
    # Help Topics

    my $OverrideMessage = "
==========================================================

To specify one or more change requests to associate with a
batch of files without displaying the user interface: 

1. Set the environment variable CQCC_AUTO_ASSOCIATE to the
associations you want to make before starting cleartool or ClearCase
Explorer.

If enabled at your site, use this option to specify one or more change
requests that you want to associate with files on checkout and checkin
operations.  The integration uses the change requests that you specify
rather than prompting you through the user interface.  The ApplyToAll
mechanism works only for files being versioned in a single checkin or
checkout command.  This option lets you handle large batches of files
in multiple checkin and checkout commands.

Use the same conventions used in the Type In option in the user
interface to specify change requests.  For example, \"SAMPL1,2,3\"
identifies change request IDs 1, 2, and 3 in the SAMPL user database.

The values you specify remain in effect until you unset the option or
set it to \"\".  On checkin operations, the integration uses the values
you specify with this option to override associations you made on
checkouts.  Specify \"-\" to set the option to select no change
requests.  If errors occur, the integration displays them and starts
the user interface for associating change requests.";

    &AddMsg("GUI_HelpMain", [],
"このダイアログ ボックスでは、ClearQuest データベース内 1 つ以上のレコードと
アプリケーション内の ClearQuest エレメントを検索し、関連付けることができます。

ダイアログ ボックスの上半分には、現在のバージョンと関連付ける予\定の
レコードが表\示されます。 [OK] または [すべてに適用] をクリックして、
関連付けをデータベースにコミットします。 アプリケーションが複数の
関連付けをサポートしている場合は、[すべてに適用] のみをクリックして、
レコードをアプリケーションの複数のバージョンと関連付けたり、または
関連付け解除を行ったりします。 このダイアログ ボックスで行った
関連付けの変更を取り消すには、[キャンセル] をクリックします。

ダイアログ ボックスの下半分では、クエリーを参照して必要な
レコードを見つけ、それらのレコードを [関連付けられたレコード]
リストに追加することができます。

 ==========================================================

レコードとバージョンを関連付けるには、以下のようにします。

1. [参照] をクリックして、既存のクエリーおよびその結果に必要なレコードを
見つけます。 [クエリーの選択] ダイアログボックスで、クエリーを選択し、
[OK] をクリックし、新しい結果が表\示されるまで待ちます。 

メモ: ローカル サイトのポリシーによっては、 [参照] ボタンが
使用不能\になっている場合があります。

2. 選択したクエリーがクエリー ウィンドウに表\示されたら、
結果グリッドをスクロールして必要なレコードを見つけて、選択します。 
複数の関連付けがアプリケーションによってサポートされる場合、
Ctrl+クリックおよび Shift+クリックで複数のレコードを選択します。

メモ: 列見出しの右端をクリックおよびドラッグして、列のサイズを
変更します。 列の見出しをクリックして、その列の値をソ\ート基準にしてレコードの
ソ\ート順序を変更します (昇順または降順のいずれか)。

3. 選択されたレコードを [関連付けられたレコード] リストに追加するには、
[関連付け] をクリックします。 (これらのレコードは、[OK] または
[すべてに適用] をクリックするまではデータベースにはコミットされません。) 

4. 探しているレコードが表\示されない場合は、[ID を入力] をクリックして、
レコードの ID を直接入力してください。 [ID を入力] 操作をコミットすると、
入力されたすべての ID は、サイト管理者によって設定されたローカル制限下に
入ります。

5. 新規レコードの作成または新規クエリーの定義を行うには、ClearQuest を
通常通りに開始し、情報を保存して、統合ウィンドウで [リフレッシュ] を
クリックして、最新のクエリー結果およびリストを表\示します。

6. [関連付けられたレコード] ダイアログで、[OK] をクリックして関連付けを
コミットし、アプリケーションに戻ります。

 ==========================================================

レコードとバージョンの関連付け解除を行うには、以下のようにします。

1. [関連付けられたレコード] リストでレコードを選択します。

2. [関連付け解除] をクリックします。 レコードはリストから削除されます。

3. [OK] または [すべてに適用] をクリックして、変更をコミットし、
アプリケーションに戻ります。

 ==========================================================

現在のデータベースを変更するには、以下のようにします。 

メモ: このチェックアウトに既存の関連付けがある場合には、データベースを
変更することはできません。

1. データベースをクリックします。 許可されるデータベースのリストが
表\示されます。 

2. 関連付けを行うデータベースを選択します。 

ログインしていたデータベースとログイン情報が異なる場合は、ログイン情報を求める
プロンプトが出されます。 使用していたレコード タイプが新規データベースで
サポートされない場合は、別のレコード タイプが自動的に選択されます。 
現在のクエリーが新規データベースではサポートされない場合、STANDARD
クエリーが設定されます。

 ==========================================================

現在のレコード タイプを変更するには、以下のようにします。

1. [レコード タイプ] をクリックします。 許可されるレコード タイプの
リストが表\示されます。 

2. 関連付けを行うレコード タイプを選択します。 


==========================================================

ユーザー インターフェイスを表\示しないで、ファイルのバッチと関連付ける
1 つ以上の変更依頼を指定するには、以下のようにします。 

1. cleartool または ClearCase エクスプローラを開始する前に、
行う関連付けに対して環境変数 CQCC_AUTO_ASSOCIATE を設定します。

サイトで有効である場合、このオプションを使用して、チェックアウトまたは
チェックイン操作でファイルに関連付ける 1 つ以上の変更依頼を指定します。  
統合では、ユーザー インターフェイスを通してプロンプトを出すのではなく、
この指定された変更依頼を使用します。  単一のチェックインまたはチェックアウト
コマンドでバージョン付けされるファイルの場合にのみ、[すべてに適用] 機能\を
使用できます。  このオプションにより、複数のチェックイン コマンドおよび
チェックアウト コマンドでファイルの大量のバッチを扱うことができます。

ユーザー インターフェイスの [タイプ] オプションで使用したものと同じ
規則を使用して、変更依頼を指定します。  例えば、\"SAMPL1,2,3\" は、
SAMPL ユーザー データベース内の変更依頼 ID 1、2、および 3 を示します。

指定した値は、オプションを設定解除するか、または \"\" に設定するまで有効です。  
チェックイン操作の際に、統合は、このオプションで指定する値を使用して
チェックアウトで行った関連付けをオーバーライドします。  変更依頼を選択しないように
オプションを設定する場合は、\"-\" を指定します。  エラーが生じた場合、統合は
それらのエラーを表\示し、変更依頼の関連付け用のユーザー インターフェイスを開始します。");

##################################################
#::::MENU_*:  TriggerCQCC Menu help

    &AddMsg("MENU_ASSOCIATION", [],
"このメニューでは、ClearCase バージョンと 1 つ以上の ClearQuest 変更依頼との
関連付けを行うことができます。 以下のオプションがあります。

* OK - 関連付けをコミットする: 依頼した関連付けを行い、終了します。

* [キャンセル]: 変更を行わないで終了し、ここまで続いた ClearCase 操作を終了します。 
チェックアウト操作をキャンセルすると、ファイルのチェックアウトは自動的にキャンセル
されるため、Clearcase 警告が表\示されることがありますが、無視できます。 

* [ヘルプ]: このメッセージを印刷します。 

* -------: (メニュー セパレータ)

* [クエリー] - ClearQuest クエリーから選択: このオプションは、ローカル管理者によって
定義されたクエリーの内容を表\示し、選択することのできる変更依頼を表\示します。 
ローカル ポリシーに従って、1 つまたは複数の項目を選択します。

* [タイプ] - キーボードから関連付けを入力: このオプションでは、スペースまたは
コンマで区切った 1 つ以上の変更依頼 ID を直接入力できます。

* [関連付けの確認]: このオプションでは、現在選択されている関連付けが表\示され、
1 つ以上の項目をリストから削除することができます。 メニュー自体に、現在
関連付けられている変更依頼 ID が表\示されます。 選択すると、同じ変更依頼の
詳細なリストが表\示されます。 ここで、削除する項目を選択するか、または削除を
行わないで戻る (キャンセル/RETURN を押す) ことができます。

* -------: (メニュー セパレータ)

* [データベース]: 現在のデータベース名を表\示し、別のデータベースに変更できる
ようにします。

* [レコード タイプ]: 作業中である現在のレコード タイプ (障害、変更依頼など) を
表\示し、現在のデータベースが複数のレコード タイプをサポートする場合、別のレコード
タイプに変更できるようにします。

* [パス名]: チェックインまたはチェックアウトしている項目を表\示します。
この項目を選択すると、可能\な場合は詳細情報が表\示されます。

* [クエリー名]: 上記のクエリー オプションで使用されている現在のクエリーを表\示します。
このオプションが表\示されると、構\成ファイル (ローカル) または ClearQuest データベース
自体で定義されている代替クエリーのリストが提示されます。 どのクエリーが表\示されるかは、
サイト管理者によって決定されます。 


==========================================================

ユーザー インターフェイスを表\示しないで、ファイルのバッチと関連付ける
1 つ以上の変更依頼を指定するには、以下のようにします。 

1. cleartool または ClearCase エクスプローラを開始する前に、
行う関連付けに対して環境変数 CQCC_AUTO_ASSOCIATE を設定します。

サイトで有効である場合、このオプションを使用して、チェックアウトまたは
チェックイン操作でファイルに関連付ける 1 つ以上の変更依頼を指定します。  
統合では、ユーザー インターフェイスを通してプロンプトを出すのではなく、
この指定された変更依頼を使用します。  単一のチェックインまたはチェックアウト
コマンドでバージョン付けされるファイルの場合にのみ、[すべてに適用] 機能\を
使用できます。  このオプションにより、複数のチェックイン コマンドおよび
チェックアウト コマンドでファイルの大量のバッチを扱うことができます。

ユーザー インターフェイスの [タイプ] オプションで使用したものと同じ
規則を使用して、変更依頼を指定します。  例えば、\"SAMPL1,2,3\" は、
SAMPL ユーザー データベース内の変更依頼 ID 1、2、および 3 を示します。

指定した値は、オプションを設定解除するか、または \"\" に設定するまで有効です。  
チェックイン操作の際に、統合は、このオプションで指定する値を使用して
チェックアウトで行った関連付けをオーバーライドします。  変更依頼を選択しないように
オプションを設定する場合は、\"-\" を指定します。  エラーが生じた場合、統合は
それらのエラーを表\示し、変更依頼の関連付け用のユーザー インターフェイスを開始します。");

    #----------------------------------------
    &AddMsg("TITLE_ASSOCIATION_MENU", ["<KEY>"],
"CQ 関連付けメニュー:項目を選び %s を押す");

################################################################
#:::TCM_*:    Trigger Cache Mgr messages
#::::TCM_E:  Error messages

    &AddMsg("TCM_E_CACHE_ACCESS", [],
"ベース CC/CQ 統合キャッシュ マネージャには
中央キャッシュ ディレクトリへのアクセスが必要です");

    &AddMsg("TCM_E_NONEXIST_DIR", ["<PATH>"],
"ベース CC/CQ 統合キャッシュ マネージャは、存在しないディレクトリ
(%s) を処理できません");

    &AddMsg("TCM_E_FAILED_POST", ["<PATH>"],
"バッチを正常にポストすることに失敗しました。
%s を調査してください");

    &AddMsg("TCM_E_CQLOGIN_UNSUPPORTED", [],
"CM_CQLOGIN 機能\は Clearcase 7.0.1 より前のリリースではサポートされません。キャッシュを使用してください\n");

    &AddMsg("TCM_E_CQLOGIN_FAILED", [],
"ClearQuest パスワードの復号に失敗しました");

#::::TCM_T:  Tags for other messages

    &AddMsg("TCM_T_LOG_HEADER", ["<TIME>","<CACHE_PATH>"],
"ベース CC/CQ 統合キャッシュ マネージャ: 実行中 (%s)
    キャッシュ ルート ディレクトリ: %s");

    &AddMsg("TCM_T_RUN_TOTALS", [], "合計の実行");
    &AddMsg("TCM_T_VALUE", [], "値");
    &AddMsg("TCM_T_COUNT", [], "件数");

    &AddMsg("TCM_T_PATTERN_MATCH", ["<PATTERN>","<ATTRIBS>","<HOURS>"], 
"パス名はパターン %s - %s
と一致します (経過時間 = %s 時間)");

    &AddMsg("TCM_T_UNKNOWN_COUNT", ["<NAME>", "<VALUE>"], 
"不明な件数値 (%s=%s)");

    &AddMsg("TCM_T_INTERESTING_FILE", [], 
"ファイルは診断の目的に役立つかもしれません");

    &AddMsg("TCM_T_UNKNOWN_FILE_PATTERN", ["<NAME>", "<VALUE>"], 
"不明なファイル パターン属性 (%s=%s)");

    &AddMsg("TCM_T_FILE_UNEXPECTED", [],
"警告: ファイルは、期待されるファイル名パターンと一致しません。
  　　  管理者が調査して手動で削除する必要があります");

    &AddMsg("TCM_T_RULE_OVER_AGE", ["<RULENAME>","<AGE>","<AGELIMIT>"],
"規則 %s (経過時間 %s 時間 > %s 時間)");

    &AddMsg("TCM_T_WOULD_DELETE_FILE", [],
"ファイルを削除します ");

    &AddMsg("TCM_T_CANT_DELETE_FILE", [],
"エラー: ファイルを削除できません");

    &AddMsg("TCM_T_DELETED_FILE", ["<REASON>"],
"削除されたファイル (%s)");

    &AddMsg("TCM_T_WOULD_POST_BATCH", ["<PATHNAME>"],
"バッチ ファイル %s をポストします");

    &AddMsg("TCM_T_POSTING_BATCH", ["<COMMAND>"],
"バッチをポストしています: コマンド
%s");

    &AddMsg("TCM_T_WOULD_DELETE_DIR", ["<AGE>"],
"すべての内容が %s 時間以上経過したものであるため、ディレクトリを削除します");

    &AddMsg("TCM_T_CANT_DELETE_DIR", [],
"エラー: ディレクトリを削除できません。ファイルは残ります。");

    &AddMsg("TCM_T_CANT_DELETE_DIR2", ["<PATH>"],
"エラー: ディレクトリ %s を削除できません");

    &AddMsg("TCM_T_DELETED_DIR", ["<REASON>"],
"削除されたディレクトリ (規則 %s)");

#:::TM_*:    Timer class messages

}

######################################################################
#::function AddMsg
# 
# This internal convenience function is used to add messages during 
# initialization
#
######################################################################

sub AddMsg {
    my ($ckey, $args, $msg) = @_;
    $arguments{$ckey} = $args ? $args : [];
    my ($status,$msgLocal) = $g_self->ConvertString($msg, "UTF8_CODEPAGE", "LOCAL_CODEPAGE");
    $catalog{$ckey} = $msgLocal;
}

######################################################################
#::method new

=over 6

=item C<new CQCC::MsgCat_Japanese()>

This constructor calls the super classes new function then its
own Initialize() method in order to load the message catalog. 

=back

=cut

######################################################################

sub new { 
   my $proto = shift;
   my $class = ref($proto) || $proto;  # Object or class name
   my $self;
   
   # CCperl doesn't support SUPER so use direct reference to parent
   $self = new CQCC::MsgCat();

   $self->{CLASSNAME} = "CQCC::MsgCat_Japanese";
   
   $self->{IO_CODEPAGE} = "LOCAL_CODEPAGE";
   $self->{CONVERSION_ENABLE} = 1;
   $self->{CONVERSION_ASCII_CHECK} = 1;
   $g_self = $self;
   
   bless($self, $class);

   # In subclasses, make sure to follow this pattern:
   #    Set local working catalog and arglists hashlists to current
   #    values, initialize adds messages, then restore the catalogs. 

   #%arguments = \$self->{ARGLISTS};
   #%catalog = \$self->{CATALOG};

   %arguments = ();
   %catalog = ();

   $self->Initialize();

   $self->{ARGLISTS} = \%arguments;
   $self->{CATALOG} = \%catalog;

   return $self;
}

#################################################################
#YesNo() Deleted. Please use parent method

######################################################################
#::Tail
#################################################################

1;
